/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */

/*
    Rosegarden
    A MIDI and audio sequencer and musical notation editor.
    Copyright 2000-2012 the Rosegarden development team.

    Other copyrights also apply to some parts of this work.  Please
    see the AUTHORS file and individual file headers for details.

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.  See the file
    COPYING included with this distribution for more information.
*/

#ifndef _RG_TIMESIGSEGMENTMAPPER_H_
#define _RG_TIMESIGSEGMENTMAPPER_H_

#include "SpecialSegmentMapper.h"
#include <QString>

namespace Rosegarden
{

class RosegardenDocument;

class TimeSigSegmentMapper : public SpecialSegmentMapper
{
    friend class SegmentMapperFactory;

public:

protected:
    TimeSigSegmentMapper(RosegardenDocument *doc) :
	SpecialSegmentMapper(doc) {}

    // overrides from SegmentMapper
    virtual int calculateSize();

    // override from SegmentMapper
    virtual void fillBuffer();

    virtual bool shouldPlay(MappedEvent *evt, RealTime /*startTime*/);
};


}

#endif
